@@ -84,7 +84,8 @@ static int parse_config_property(const char *file, const char *line,
 
 static void init_config_properties(ConfigProperties *conf);
 
-static void write_config_properties(FILE *stream, ConfigProperties *conf);
+static void write_config_properties(FILE *stream, ConfigProperties *conf,
+                                    char *locale);
 
 
 /*
@@ -215,6 +216,7 @@ int nv_write_config_file(const char *filename, CtrlHandles *h,
     NVCTRLAttributeValidValuesRec valid;
     uint32 mask;
     char *tmp_d_str, *tmp, *prefix, scratch[4];
+    char *locale = "C";
 
     stream = fopen(filename, "w");
     if (!stream) {
@@ -237,9 +239,21 @@ int nv_write_config_file(const char *filename, CtrlHandles *h,
     fprintf(stream, "# Generated on %s", ctime(&now));
     fprintf(stream, "#\n");
     
+    /*
+     * set the locale to "C" before writing the configuration file to
+     * reduce the risk of locale related parsing problems.  Restore
+     * the original locale before exiting this function.
+     */
+
+    if (setlocale(LC_NUMERIC, "C") == NULL) {
+        nv_warning_msg("Error writing configuration file '%s': could "
+                       "not set the locale 'C'.", filename);
+        locale = conf->locale;
+    }
+
     /* write the values in ConfigProperties */
 
-    write_config_properties(stream, conf);
+    write_config_properties(stream, conf, locale);
 
     /* for each screen, query each attribute in the table */
 
@@ -383,6 +397,8 @@ int nv_write_config_file(const char *filename, CtrlHandles *h,
         p = p->next;
     }
 
+    setlocale(LC_NUMERIC, conf->locale);
+
     /* close the configuration file */
 
     ret = fclose(stream);
@@ -707,7 +723,7 @@ static int parse_config_property(const char *file, const char *line, ConfigPrope
  * each property is enabled or disabled.
  */
 
-static void write_config_properties(FILE *stream, ConfigProperties *conf)
+static void write_config_properties(FILE *stream, ConfigProperties *conf, char *locale)
 {
     ConfigPropertiesTableEntry *t;
 
@@ -715,7 +731,7 @@ static void write_config_properties(FILE *stream, ConfigProperties *conf)
     fprintf(stream, "# ConfigProperties:\n");
     fprintf(stream, "\n");
 
-    fprintf(stream, "RcFileLocale = %s\n", conf->locale);
+    fprintf(stream, "RcFileLocale = %s\n", locale);
 
     for (t = configPropertyTable; t->name; t++) {
         fprintf(stream, "%s = %s\n", t->name,
