@@ -28,7 +28,7 @@
 #include <gtk/gtk.h>
 #include <NvCtrlAttributes.h>
 
-#include "glx_banner.h"
+#include "ctkimage.h"
 #include "ctkglx.h"
 #include "ctkconfig.h"
 #include "ctkhelp.h"
@@ -205,12 +205,10 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
     GObject *object;
     CtkGLX *ctk_glx;
     GtkWidget *label;
-    GtkWidget *image;
-    GtkWidget *frame;
+    GtkWidget *banner;
     GtkWidget *hseparator;
     GtkWidget *hbox, *hbox2;
     GtkWidget *vbox, *vbox2;
-    GtkWidget *alignment;
     GtkWidget *table;
     GtkWidget *scrollWin;
     GtkWidget *event;    /* For setting the background color to white */
@@ -218,9 +216,6 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
 
     ReturnStatus ret;
 
-    guint8 *image_buffer = NULL;
-    const nv_image_t *img;    
-
     char * glx_info_str = NULL;               /* Test if GLX supported */
     GLXFBConfigAttr *fbconfig_attribs = NULL; /* FBConfig data */
     int i;                                    /* Iterator */
@@ -268,20 +263,9 @@ GtkWidget* ctk_glx_new(NvCtrlAttributeHandle *handle,
     gtk_box_set_spacing(GTK_BOX(ctk_glx), 10);
 
     /* Image banner */
-    alignment = gtk_alignment_new(0, 0, 0, 0);
-    frame = gtk_frame_new(NULL);
-    img = &glx_banner_image;
-    image_buffer = decompress_image_data(img);
-    image = gtk_image_new_from_pixbuf
-        (gdk_pixbuf_new_from_data(image_buffer, GDK_COLORSPACE_RGB,
-                                  FALSE, 8, img->width, img->height,
-                                  img->width * img->bytes_per_pixel,
-                                  free_decompressed_image, NULL));
-    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-    gtk_container_add(GTK_CONTAINER(frame), image);
-    gtk_container_add(GTK_CONTAINER(alignment), frame);
-    gtk_box_pack_start(GTK_BOX(ctk_glx), alignment, FALSE, FALSE, 0);
 
+    banner = ctk_banner_image_new(BANNER_ARTWORK_GLX);
+    gtk_box_pack_start(GTK_BOX(ctk_glx), banner, FALSE, FALSE, 0);
     
     /* Determine if GLX is supported */
     ret = NvCtrlGetStringAttribute(ctk_glx->handle,
