@@ -30,10 +30,8 @@
 
 G_BEGIN_DECLS
 
-GtkWidget*  ctk_image_new          (const nv_image_t *);
-GtkWidget*  ctk_image_new_from_xpm (const char **);
-GtkWidget*  ctk_image_dupe         (GtkImage *image);
-GtkWidget*  ctk_banner_image_new   (const nv_image_t *);
+GtkWidget*  ctk_image_new        (const nv_image_t *);
+GtkWidget*  ctk_banner_image_new (BannerArtworkType artwork);
 
 G_END_DECLS
 
