@@ -27,12 +27,11 @@
 
 #include "NvCtrlAttributes.h"
 
-#include "antialiasing_banner.h"
-
 #include "ctkmultisample.h"
 
 #include "ctkconfig.h"
 #include "ctkhelp.h"
+#include "ctkimage.h"
 
 
 /* local prototypes */
@@ -184,14 +183,11 @@ GtkWidget *ctk_multisample_new(NvCtrlAttributeHandle *handle,
     GObject *object;
     CtkMultisample *ctk_multisample;
     GtkWidget *hbox, *vbox = NULL;
-    GtkWidget *image;
+    GtkWidget *banner;
     GtkWidget *frame;
     GtkWidget *check_button;
     GtkWidget *scale;
     
-    guint8 *image_buffer = NULL;
-    const nv_image_t *img;
-
     gint val, app_control, override, i;
     
     NVCTRLAttributeValidValuesRec valid;
@@ -214,21 +210,9 @@ GtkWidget *ctk_multisample_new(NvCtrlAttributeHandle *handle,
     hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(object), hbox, FALSE, FALSE, 0);
 
-    frame = gtk_frame_new(NULL);
-    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
-    gtk_box_pack_start(GTK_BOX(hbox), frame, FALSE, FALSE, 0);
+    banner = ctk_banner_image_new(BANNER_ARTWORK_ANTIALIAS);
+    gtk_box_pack_start(GTK_BOX(hbox), banner, TRUE, TRUE, 0);
 
-    img = &antialiasing_banner_image;
-    image_buffer = decompress_image_data(img);
-
-    image = gtk_image_new_from_pixbuf
-        (gdk_pixbuf_new_from_data(image_buffer, GDK_COLORSPACE_RGB,
-                                  FALSE, 8, img->width, img->height,
-                                  img->width * img->bytes_per_pixel,
-                                  free_decompressed_image, NULL));
-
-    gtk_container_add(GTK_CONTAINER(frame), image);
-    
     /* FSAA slider */
 
     ret = NvCtrlGetValidAttributeValues(handle, NV_CTRL_FSAA_MODE, &valid);
@@ -768,20 +752,16 @@ static void fsaa_update_received(GtkObject *object,
     CtkEventStruct *event_struct;
     CtkMultisample *ctk_multisample;
     GtkRange *range;
-    gint val;
 
     event_struct = (CtkEventStruct *) arg1;
     ctk_multisample = CTK_MULTISAMPLE(user_data);
     range = GTK_RANGE(ctk_multisample->fsaa_scale);
 
-    val = map_nv_ctrl_fsaa_value_to_slider(ctk_multisample,
-                                           event_struct->value);
-
     g_signal_handlers_block_by_func(G_OBJECT(range),
                                     G_CALLBACK(fsaa_value_changed),
                                     (gpointer) ctk_multisample);
     
-    gtk_range_set_value(range, val);
+    gtk_range_set_value(range, event_struct->value);
     
     g_signal_handlers_unblock_by_func(G_OBJECT(range),
                                       G_CALLBACK(fsaa_value_changed),
