@@ -329,6 +329,7 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **handles, gint num_handles,
     GtkCellRenderer *renderer;
     GtkTreeSelection *selection;
     GtkTreeModel *model;
+    GtkTreeIter iter;
     GtkTextTagTable *tag_table;
 
     GtkTextBuffer *help;
@@ -489,7 +490,6 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **handles, gint num_handles,
 
     for (i = 0; i < num_handles; i++) {
 
-        GtkTreeIter iter;
         gchar *screen_name;
         GtkWidget *child;
 
@@ -658,6 +658,12 @@ GtkWidget *ctk_window_new(NvCtrlAttributeHandle **handles, gint num_handles,
     gtk_tree_view_expand_all(ctk_window->treeview);
     gtk_tree_view_columns_autosize(ctk_window->treeview);
 
+    /* Make sure the first item is selected */
+    if ( gtk_tree_model_get_iter_first(model, &iter) ) {
+        gtk_tree_selection_select_iter(selection, &iter);
+    }
+
+
     /* set the window title */
     
     gtk_window_set_title(GTK_WINDOW(object), "NVIDIA X Server Settings");
