@@ -45,7 +45,7 @@ static int process_attribute_assignments(int, char**, const char *);
 
 static int query_all(const char *);
 
-static void print_valid_values(char *, uint32, NVCTRLAttributeValidValuesRec);
+static void print_valid_values(char *, NVCTRLAttributeValidValuesRec);
 
 static int validate_value(CtrlHandles *h, ParsedAttribute *a, uint32 d,
                           int screen, char *whence);
@@ -96,10 +96,9 @@ int nv_process_assignments_and_queries(Options *op)
 uint32 *nv_get_enabled_display_devices(int n, NvCtrlAttributeHandle **h)
 {
     ReturnStatus status;
-    uint32 *d;
-    int screen;
+    int *d, screen;
     
-    d = malloc(sizeof(uint32) * n);
+    d = malloc(sizeof(int) * n);
     
     for (screen = 0; screen < n; screen++) {
         if (!h[screen]) {
@@ -118,7 +117,7 @@ uint32 *nv_get_enabled_display_devices(int n, NvCtrlAttributeHandle **h)
         }
     }
 
-    return d;
+    return (uint32 *)d;
 
 } /* nv_get_enabled_display_devices() */
 
@@ -186,17 +185,6 @@ void nv_free_ctrl_handles(CtrlHandles *h)
     if (h->display) free(h->display);
 
     if (h->dpy) {
-
-        /*
-         * XXX It is unfortunate that the display connection needs
-         * to be closed before the backends have had a chance to
-         * tear down their state. If future backends need to send
-         * protocol in this case or perform similar tasks, we'll
-         * have to add e.g. NvCtrlAttributeTearDown(), which would
-         * need to be called before XCloseDisplay().
-         */
-        XCloseDisplay(h->dpy);
-        h->dpy = NULL;
         
         for (i = 0; i < h->num_screens; i++) {
             NvCtrlAttributeClose(h->h[i]);
@@ -206,6 +194,8 @@ void nv_free_ctrl_handles(CtrlHandles *h)
         if (h->d) free(h->d);
         if (h->h) free(h->h);
         if (h->screen_names) free(h->screen_names);
+        
+        XCloseDisplay(h->dpy);
     }
     
     free(h);
@@ -395,15 +385,8 @@ static int validate_value(CtrlHandles *h, ParsedAttribute *a, uint32 d,
         }
         break;
     case ATTRIBUTE_TYPE_RANGE:
-        if (a->flags & NV_PARSER_TYPE_PACKED_ATTRIBUTE) {
-            if (((a->val >> 16) < (valid.u.range.min >> 16)) ||
-                ((a->val >> 16) > (valid.u.range.max >> 16)) ||
-                ((a->val & 0xffff) < (valid.u.range.min & 0xffff)) ||
-                ((a->val & 0xffff) > (valid.u.range.max & 0xffff)))
-                bad_val = NV_TRUE;
-        } else {
-            if ((a->val < valid.u.range.min) || (a->val > valid.u.range.max))
-                bad_val = NV_TRUE;
+        if ((a->val < valid.u.range.min) || (a->val > valid.u.range.max)) {
+            bad_val = NV_TRUE;
         }
         break;
     case ATTRIBUTE_TYPE_INT_BITS:
@@ -418,19 +401,11 @@ static int validate_value(CtrlHandles *h, ParsedAttribute *a, uint32 d,
     }
 
     if (bad_val) {
-        if (a->flags & NV_PARSER_TYPE_PACKED_ATTRIBUTE) {
-            nv_warning_msg("The value pair %d,%d for attribute '%s' (%s%s) "
-                           "specified %s is invalid.",
-                           a->val >> 16, a->val & 0xffff,
-                           a->name, h->screen_names[screen],
-                           d_str, whence);
-        } else {
-            nv_warning_msg("The value %d for attribute '%s' (%s%s) "
-                           "specified %s is invalid.",
-                           a->val, a->name, h->screen_names[screen],
-                           d_str, whence);
-        }
-        print_valid_values(a->name, a->flags, valid);
+        nv_warning_msg("The value %d for attribute '%s' (%s%s) "
+                       "specified %s is invalid.",
+                       a->val, a->name, h->screen_names[screen],
+                       d_str, whence);
+        print_valid_values(a->name, valid);
         return NV_FALSE;
     }
     return NV_TRUE;
@@ -444,8 +419,7 @@ static int validate_value(CtrlHandles *h, ParsedAttribute *a, uint32 d,
  * attribute.
  */
 
-static void print_valid_values(char *name, uint32 flags,
-                               NVCTRLAttributeValidValuesRec valid)
+static void print_valid_values(char *name, NVCTRLAttributeValidValuesRec valid)
 {
     int bit, first, last;
     char str[256];
@@ -455,11 +429,7 @@ static void print_valid_values(char *name, uint32 flags,
 
     switch (valid.type) {
     case ATTRIBUTE_TYPE_INTEGER:
-        if (flags & NV_PARSER_TYPE_PACKED_ATTRIBUTE) {
-            nv_msg(INDENT, "'%s' is a packed integer attribute.", name);
-        } else {
-            nv_msg(INDENT, "'%s' is an integer attribute.", name);
-        }
+        nv_msg(INDENT, "'%s' is an integer attribute.", name);
         break;
         
     case ATTRIBUTE_TYPE_BITMASK:
@@ -472,16 +442,9 @@ static void print_valid_values(char *name, uint32 flags,
         break;
         
     case ATTRIBUTE_TYPE_RANGE:
-        if (flags & NV_PARSER_TYPE_PACKED_ATTRIBUTE) {
-            nv_msg(INDENT, "The valid values for '%s' are in the ranges "
-                   "%d - %d, %d - %d (inclusive).", name,
-                   valid.u.range.min >> 16, valid.u.range.max >> 16,
-                   valid.u.range.min & 0xffff, valid.u.range.max & 0xffff);
-        } else {
-            nv_msg(INDENT, "The valid values for '%s' are in the range "
-                   "%d - %d (inclusive).", name,
-                   valid.u.range.min, valid.u.range.max);
-        }
+        nv_msg(INDENT, "The valid values for '%s' are in the range "
+               "%d - %d (inclusive).", name,
+               valid.u.range.min, valid.u.range.max);
         break;
 
     case ATTRIBUTE_TYPE_INT_BITS:
@@ -559,10 +522,6 @@ static int query_all(const char *display_name)
         "Attribute '%s' (screen: %s): 0x%08x.";
     static const char *__fmt_str_hex_display =
         "Attribute '%s' (screen: %s; display: %s): 0x%08x.";
-    static const char *__fmt_str_packed_int =
-        "Attribute '%s' (screen: %s): %d,%d.";
-    static const char *__fmt_str_packed_int_display =
-        "Attribute '%s' (screen: %s; display: %s): %d,%d.";
     
     h = nv_alloc_ctrl_handles(display_name);
 
@@ -617,9 +576,6 @@ static int query_all(const char *display_name)
                 if (valid.type == ATTRIBUTE_TYPE_BITMASK) {
                     fmt = __fmt_str_hex;
                     fmt_display = __fmt_str_hex_display;
-                } else if (a->flags & NV_PARSER_TYPE_PACKED_ATTRIBUTE) {
-                    fmt = __fmt_str_packed_int;
-                    fmt_display = __fmt_str_packed_int_display;
                 } else {
                     fmt = __fmt_str_int;
                     fmt_display = __fmt_str_int_display;
@@ -630,30 +586,19 @@ static int query_all(const char *display_name)
                     tmp_d_str =
                         display_device_mask_to_display_device_name(mask);
                     
-                    if (a->flags & NV_PARSER_TYPE_PACKED_ATTRIBUTE) {
-                        nv_msg(INDENT, fmt_display, a->name,
-                               h->screen_names[screen], tmp_d_str,
-                               val >> 16, val & 0xffff);
-                    } else {
-                        nv_msg(INDENT, fmt_display, a->name,
-                               h->screen_names[screen], tmp_d_str, val);
-                    }
+                    nv_msg(INDENT, fmt_display, a->name,
+                           h->screen_names[screen], tmp_d_str, val);
                     
                     free(tmp_d_str);
 
-                    print_valid_values(a->name, a->flags, valid);
+                    print_valid_values(a->name, valid);
 
                     continue;
 
                 } else {
-                    if (a->flags & NV_PARSER_TYPE_PACKED_ATTRIBUTE) {
-                        nv_msg(INDENT, fmt, a->name, h->screen_names[screen],
-                               val >> 16, val & 0xffff);
-                    } else {
-                        nv_msg(INDENT, fmt, a->name, h->screen_names[screen],val);
-                    }
+                    nv_msg(INDENT, fmt, a->name, h->screen_names[screen], val);
 
-                    print_valid_values(a->name, a->flags, valid);
+                    print_valid_values(a->name, valid);
 
                     /* fall through to exit_bit_loop */
                 }
@@ -719,14 +664,8 @@ static int process_parsed_attribute_internal(CtrlHandles *h,
         }
         
         if (verbose) {
-            if (a->flags & NV_PARSER_TYPE_PACKED_ATTRIBUTE) {
-                nv_msg("  ", "Attribute '%s' (%s%s) assigned value %d,%d.",
-                       a->name, h->screen_names[screen], str,
-                       a->val >> 16, a->val & 0xffff);
-            } else {
-                nv_msg("  ", "Attribute '%s' (%s%s) assigned value %d.",
-                       a->name, h->screen_names[screen], str, a->val);
-            }
+            nv_msg("  ", "Attribute '%s' (%s%s) assigned value %d.",
+                   a->name, h->screen_names[screen], str, a->val);
         }
 
     } else { /* query */
@@ -745,15 +684,9 @@ static int process_parsed_attribute_internal(CtrlHandles *h,
                          NvCtrlAttributesStrError(status));
             return NV_FALSE;
         } else {
-            if (a->flags & NV_PARSER_TYPE_PACKED_ATTRIBUTE) {
-                nv_msg("  ", "Attribute '%s' (%s%s): %d,%d.",
-                       a->name, h->screen_names[screen], str,
-                       a->val >> 16, a->val & 0xffff);
-            } else {
-                nv_msg("  ", "Attribute '%s' (%s%s): %d.",
-                       a->name, h->screen_names[screen], str, a->val);
-            }
-            print_valid_values(a->name, a->flags, valid);
+            nv_msg("  ", "Attribute '%s' (%s%s): %d.",
+                   a->name, h->screen_names[screen], str, a->val);
+            print_valid_values(a->name, valid);
         }
     }
 
